pub trait PacketHeader { // Required method fn length(&self) -> usize; // Provided method fn size_of() -> usize where Self: Sized { ... } }
Represents a packet header.
Offset from beginning of the header to start of the payload. It includes the length of any variable-sized options and tags.
Size of the fixed portion of the header in bytes.